
## CATO-CLI - mutation.xdr.addStoryComment:
[Click here](https://api.catonetworks.com/documentation/#mutation-addStoryComment) for documentation on this operation.

### Usage for mutation.xdr.addStoryComment:

`catocli mutation xdr addStoryComment -h`

`catocli mutation xdr addStoryComment <json>`

`catocli mutation xdr addStoryComment "$(cat < addStoryComment.json)"`

`catocli mutation xdr addStoryComment '{"addStoryCommentInput": {"storyId": {"storyId": "ID"}, "text": {"text": "String"}}}'`

#### Operation Arguments for mutation.xdr.addStoryComment ####
`accountId` [ID] - (required) N/A 
`addStoryCommentInput` [AddStoryCommentInput] - (required) N/A 
